/**
 * Copyright      2023     Xiaomi Corporation (authors: Wei Kang)
 *
 * See LICENSE for clarification regarding multiple authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef TEXTSEARCH_PYTHON_CSRC_SUFFIX_ARRAY_H_
#define TEXTSEARCH_PYTHON_CSRC_SUFFIX_ARRAY_H_

#include "textsearch/python/csrc/text_search.h"

namespace fasttextsearch {

void PybindSuffixArray(py::module &m);

} // namespace fasttextsearch

#endif // TEXTSEARCH_PYTHON_CSRC_SUFFIX_ARRAY_H_
